@@ -1,19 +1,31 @@
 use strict;
 use warnings;
 package App::Whiff;
-{
-  $App::Whiff::VERSION = '0.003';
-}
 # ABSTRACT: find the first executable of a series of alternatives
-
+$App::Whiff::VERSION = '0.005';
 use File::Which ();
 
+#pod =head1 DESCRIPTION
+#pod
+#pod This module implements logic used by the F<whiff> command, which takes a number
+#pod of command names and returns the first one that exists and is executable.
+#pod
+#pod =method find_first
+#pod
+#pod   my $filename = App::Whiff->find_first(\@names);
+#pod
+#pod Given an arrayref of command names (which should I<not> be anything other than
+#pod base filename), this method either returns an absolute path to the first of the
+#pod alternatives found in the path (using L<File::Which>) or false.
+#pod
+#pod =cut
 
 sub find_first {
   my ($self, $names) = @_;
 
   my $file;
   for my $name (@$names) {
+    return $name if $name =~ m{\A/} && -x $name;
     $file = File::Which::which($name);
     return $file if $file;
   }
@@ -21,6 +33,11 @@ sub find_first {
   return;
 }
 
+#pod =method run
+#pod
+#pod This method is called by the F<whiff> program to ... well, run.
+#pod
+#pod =cut
 
 sub run {
   my ($self) = @_;
@@ -37,13 +54,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 App::Whiff - find the first executable of a series of alternatives
 
 =head1 VERSION
 
-version 0.003
+version 0.005
 
 =head1 DESCRIPTION
 
